@@ -1,12 +1,12 @@
 ######################################################################
 # diff.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: diff.inc.pl,v 1.50 2006/03/17 14:00:10 papu Exp $
+# $Id: diff.inc.pl,v 1.78 2010/12/14 22:20:00 papu Exp $
 #
-# "PyukiWiki" version 0.1.6 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2006 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2006 PyukiWiki Developers Team
+# "PyukiWiki" version 0.1.8 $$
+# Author: Nekyo
+# Copyright (C) 2004-2010 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2010 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -48,6 +48,10 @@ sub plugin_diff_action {
 	}
 	$body .= qq(</pre>);
 	$body .= qq(<hr>);
+
+
+	$body=~s/$::ismail/$::resource{diff_disable_email}/g
+		if($diff_disable_email eq 1);
 	return ('msg' => "$title\t$::resource{diff_plugin_title}", 'body' => $body, 'ispage'=>1);
 }
 1;
